package com.dzeio.openhealth.data.food

import androidx.room.Entity
import androidx.room.PrimaryKey
import com.dzeio.openhealth.data.openfoodfact.OFFProduct
import java.util.Calendar
import java.util.TimeZone

@Entity
data class Food(
    @PrimaryKey(autoGenerate = true)
    var id: Long = 0,
    var name: String,
    var serving: String,
    var quantity: Float,
    var proteins: Float,
    var carbohydrates: Float,
    var fat: Float,
    var energy: Float,

    /**
     * the url of the image
     */
    var image: String?,

    var timestamp: Long = Calendar.getInstance(TimeZone.getTimeZone("UTC")).timeInMillis,
) {
    companion object {
        fun fromOpenFoodFact(food: OFFProduct, quantity: Float? = null): Food {
            var eaten = quantity ?: food.servingQuantity ?: food.productQuantity ?: 0f
            if (eaten == 0f) {
                if (food.servingQuantity != null && food.servingQuantity != 0f) {
                    eaten = food.servingQuantity!!
                } else if (food.productQuantity != null && food.productQuantity != 0f) {
                    eaten = food.productQuantity!!
                }
            }
            return Food(
                name = food.name,
                serving = (food.servingSize ?: food.quantity ?: "unknown").replace(Regex(" +"), ""),
                quantity = eaten,
                proteins = food.nutriments.proteins,
                carbohydrates = food.nutriments.carbohydrates,
                fat = food.nutriments.fat,
                energy = food.nutriments.energy ?: (food.nutriments.energyKJ * 0.2390057361).toFloat(),
                image = food.image
            )
        }
    }
}
